---
# generated by https://github.com/hashicorp/terraform-plugin-docs
page_title: "vercel_project Resource - terraform-provider-vercel"
subcategory: ""
description: |-
  Provides a Project resource.
  A Project groups deployments and custom domains. To deploy on Vercel, you need to create a Project.
  For more detailed information, please see the Vercel documentation https://vercel.com/docs/concepts/projects/overview.
  ~> Terraform currently provides both a standalone Project Environment Variable resource (a single Environment Variable), and a Project resource with Environment Variables defined in-line via the environment field.
  At this time you cannot use a Vercel Project resource with in-line environment in conjunction with any vercel_project_environment_variable resources. Doing so will cause a conflict of settings and will overwrite Environment Variables.
---

# vercel_project (Resource)

Provides a Project resource.

A Project groups deployments and custom domains. To deploy on Vercel, you need to create a Project.

For more detailed information, please see the [Vercel documentation](https://vercel.com/docs/concepts/projects/overview).

~> Terraform currently provides both a standalone Project Environment Variable resource (a single Environment Variable), and a Project resource with Environment Variables defined in-line via the `environment` field.
At this time you cannot use a Vercel Project resource with in-line `environment` in conjunction with any `vercel_project_environment_variable` resources. Doing so will cause a conflict of settings and will overwrite Environment Variables.

## Example Usage

```terraform
# A project that is connected to a git repository.
# Deployments will be created automatically
# on every branch push and merges onto the Production Branch.
resource "vercel_project" "with_git" {
  name      = "example-project-with-git"
  framework = "nextjs"

  git_repository = {
    type = "github"
    repo = "vercel/some-repo"
  }
}

# A project that is not connected to a git repository.
# Deployments will need to be created manually through
# terraform, or via the vercel CLI.
resource "vercel_project" "example" {
  name      = "example-project"
  framework = "nextjs"
}
```

<!-- schema generated by tfplugindocs -->
## Schema

### Required

- `name` (String) The desired name for the project.

### Optional

- `build_command` (String) The build command for this project. If omitted, this value will be automatically detected.
- `dev_command` (String) The dev command for this project. If omitted, this value will be automatically detected.
- `environment` (Attributes Set) A set of Environment Variables that should be configured for the project. (see [below for nested schema](#nestedatt--environment))
- `framework` (String) The framework that is being used for this project. If omitted, no framework is selected.
- `git_repository` (Attributes) The Git Repository that will be connected to the project. When this is defined, any pushes to the specified connected Git Repository will be automatically deployed. This requires the corresponding Vercel for [Github](https://vercel.com/docs/concepts/git/vercel-for-github), [Gitlab](https://vercel.com/docs/concepts/git/vercel-for-gitlab) or [Bitbucket](https://vercel.com/docs/concepts/git/vercel-for-bitbucket) plugins to be installed. (see [below for nested schema](#nestedatt--git_repository))
- `ignore_command` (String) When a commit is pushed to the Git repository that is connected with your Project, its SHA will determine if a new Build has to be issued. If the SHA was deployed before, no new Build will be issued. You can customize this behavior with a command that exits with code 1 (new Build needed) or code 0.
- `install_command` (String) The install command for this project. If omitted, this value will be automatically detected.
- `output_directory` (String) The output directory of the project. If omitted, this value will be automatically detected.
- `public_source` (Boolean) By default, visitors to the `/_logs` and `/_src` paths of your Production and Preview Deployments must log in with Vercel (requires being a member of your team) to see the Source, Logs and Deployment Status of your project. Setting `public_source` to `true` disables this behaviour, meaning the Source, Logs and Deployment Status can be publicly viewed.
- `root_directory` (String) The name of a directory or relative path to the source code of your project. If omitted, it will default to the project root.
- `serverless_function_region` (String) The region on Vercel's network to which your Serverless Functions are deployed. It should be close to any data source your Serverless Function might depend on. A new Deployment is required for your changes to take effect. Please see [Vercel's documentation](https://vercel.com/docs/concepts/edge-network/regions) for a full list of regions.
- `team_id` (String) The team ID to add the project to.

### Read-Only

- `id` (String) The ID of this resource.

<a id="nestedatt--environment"></a>
### Nested Schema for `environment`

Optional:

- `git_branch` (String) The git branch of the Environment Variable.
- `id` (String) The ID of the Environment Variable.
- `key` (String) The name of the Environment Variable.
- `target` (Set of String) The environments that the Environment Variable should be present on. Valid targets are either `production`, `preview`, or `development`.
- `value` (String, Sensitive) The value of the Environment Variable.


<a id="nestedatt--git_repository"></a>
### Nested Schema for `git_repository`

Optional:

- `repo` (String) The name of the git repository. For example: `vercel/next.js`.
- `type` (String) The git provider of the repository. Must be either `github`, `gitlab`, or `bitbucket`.

## Import

Import is supported using the following syntax:

```shell
# Import via the team_id and project_id.
# team_id can be found in the team `settings` tab in the Vercel UI.
# project_id can be found in the project `settings` tab in the Vercel UI.
terraform import vercel_project.example team_xxxxxxxxxxxxxxxxxxxxxxxx/prj_xxxxxxxxxxxxxxxxxxxxxxxxxxxx

# If importing without a team, simply use the project ID.
terraform import vercel_project.personal_example prj_xxxxxxxxxxxxxxxxxxxxxxxxxxxx
```
